@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import sys
 from typing import Any, Dict
 
@@ -17,3 +19,12 @@ else:
 
         class TypedDict(Dict):  # type: ignore
             pass
+
+
+if sys.version_info >= (3, 10):
+    from typing import TypeAlias
+else:
+    try:
+        from typing_extensions import TypeAlias
+    except ImportError:
+        TypeAlias = type  # type: ignore
